pub trait ClientInfo<Inner> {
// Required methods
fn api_version() -> &'static str;
fn baseurl(&self) -> &str;
fn client(&self) -> &ClientWithMiddleware;
fn inner(&self) -> &Inner;
}Expand description
Interface for which an implementation is generated for all clients.
Required Methods
Sourcefn api_version() -> &'static str
fn api_version() -> &'static str
Get the version of this API.
This string is pulled directly from the source OpenAPI document and may be in any format the API selects.
Sourcefn client(&self) -> &ClientWithMiddleware
fn client(&self) -> &ClientWithMiddleware
Get the internal reqwest_middleware::ClientWithMiddleware used to make requests.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".