pub struct Token {Show 23 fields
pub address: String,
pub chain: String,
pub coingecko_coin_id: Option<String>,
pub decimals: i32,
pub description: Option<String>,
pub dev_last_token_created_at: Option<String>,
pub dev_total_tokens: Option<String>,
pub extension: Option<TokenExtra>,
pub extra: Option<TokenExtra>,
pub image_url: Option<String>,
pub market: Option<String>,
pub market_data: Option<TokenMarketData>,
pub metadata_address: Option<String>,
pub name: String,
pub social_medias: Option<TokenSocialMedias>,
pub stats: Option<TokenStats>,
pub symbol: String,
pub token_created_at: Option<i64>,
pub token_created_block_height: Option<String>,
pub token_created_slot: Option<String>,
pub token_created_tx_signature: Option<String>,
pub token_creators: Vec<TokenCreator>,
pub uri: Option<String>,
}Expand description
Token entity — mirrors TS TokenDTO extends TokenMetadataDTO.
TS uses class inheritance to flatten metadata into the top level.
Rust uses #[serde(flatten)] for the same effect.
JSON schema
{
"description": "Token entity — mirrors TS `TokenDTO extends TokenMetadataDTO`.\n\nTS uses class inheritance to flatten metadata into the top level.\nRust uses `#[serde(flatten)]` for the same effect.",
"type": "object",
"required": [
"address",
"chain",
"decimals",
"name",
"symbol"
],
"properties": {
"address": {
"examples": [
"EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v"
],
"type": "string"
},
"chain": {
"examples": [
"sol"
],
"type": "string"
},
"coingeckoCoinId": {
"examples": [
"usd-coin"
],
"type": "string"
},
"decimals": {
"examples": [
9
],
"type": "integer",
"format": "int32"
},
"description": {
"examples": [
"USDC is a stablecoin pegged to the US dollar"
],
"type": "string"
},
"devLastTokenCreatedAt": {
"examples": [
"2025-12-03T09:23:34.000Z"
],
"type": "string"
},
"devTotalTokens": {
"examples": [
"163"
],
"type": "string"
},
"extension": {
"$ref": "#/components/schemas/TokenExtra"
},
"extra": {
"$ref": "#/components/schemas/TokenExtra"
},
"imageUrl": {
"examples": [
"https://raw.githubusercontent.com/solana-labs/token-list/main/assets/mainnet/EPjFWdd5AufqSSqeM2qN1xzybapC8G4wEGGkZwyTDt1v/logo.png"
],
"type": "string"
},
"market": {
"examples": [
"USDC-SOL"
],
"type": "string"
},
"marketData": {
"$ref": "#/components/schemas/TokenMarketData"
},
"metadataAddress": {
"examples": [
"metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s"
],
"type": "string"
},
"name": {
"examples": [
"USD Coin"
],
"type": "string"
},
"socialMedias": {
"$ref": "#/components/schemas/TokenSocialMedias"
},
"stats": {
"$ref": "#/components/schemas/TokenStats"
},
"symbol": {
"examples": [
"USDC"
],
"type": "string"
},
"tokenCreatedAt": {
"examples": [
1710417600000
],
"type": "integer",
"format": "int64"
},
"tokenCreatedBlockHeight": {
"examples": [
"220000000"
],
"type": "string"
},
"tokenCreatedSlot": {
"examples": [
"230000000"
],
"type": "string"
},
"tokenCreatedTxSignature": {
"examples": [
"5dJ1BxPiFT7w7aBdkxNy2jopGZnZoLwRwS8e9GkEXrVz..."
],
"type": "string"
},
"tokenCreators": {
"type": "array",
"items": {
"$ref": "#/components/schemas/TokenCreator"
}
},
"uri": {
"examples": [
"https://arweave.net/abc123"
],
"type": "string"
}
}
}Fields
address: Stringchain: Stringcoingecko_coin_id: Option<String>decimals: i32description: Option<String>dev_last_token_created_at: Option<String>dev_total_tokens: Option<String>extension: Option<TokenExtra>extra: Option<TokenExtra>image_url: Option<String>market: Option<String>market_data: Option<TokenMarketData>metadata_address: Option<String>name: Stringstats: Option<TokenStats>symbol: Stringtoken_created_at: Option<i64>token_created_block_height: Option<String>token_created_slot: Option<String>token_created_tx_signature: Option<String>token_creators: Vec<TokenCreator>uri: Option<String>Implementations